@@ -1,7 +1,6 @@
 #ifndef dplyr_dplyr_dplyr_H
 #define dplyr_dplyr_dplyr_H
 
-#include <dplyr/registration.h>
 #include <dplyr/allow_list.h>
 #include <dplyr/checks.h>
 #include <dplyr/visitor_set/visitor_set.h>
@@ -12,7 +11,7 @@
 #include <tools/comparisons.h>
 #include <dplyr/visitors/join/join_match.h>
 #include <dplyr/visitors/vector/MultipleVectorVisitors.h>
-#include <dplyr/visitors/vector/visitor.h>
+#include <dplyr/visitors/vector/VectorVisitor.h>
 #include <dplyr/visitors/vector/visitor_impl.h>
 #include <dplyr/visitors/order/OrderVisitorImpl.h>
 #include <dplyr/visitors/join/JoinVisitor.h>
@@ -23,6 +22,5 @@
 #include <dplyr/Collecter.h>
 #include <dplyr/NamedListAccumulator.h>
 #include <tools/train.h>
-#include <dplyr/Groups.h>
 
 #endif // #ifndef dplyr_dplyr_dplyr_H
